﻿using System.Collections.Generic;
using System.Diagnostics;
using System.Windows;
using DataSource;
using Infragistics.Controls.Grids;

namespace ButtonsInColumn
{
    /// <summary>
    /// Interaction logic for MainWindow.xaml
    /// </summary>
    public partial class MainWindow : Window
    {
        public MainWindow()
        {
            InitializeComponent();
            Loaded += MainWindow_Loaded;
        }

        private void MainWindow_Loaded(object sender, RoutedEventArgs e)
        {
            XamGrid xamGrid = new XamGrid
            {
                AutoGenerateColumns = false,
                ItemsSource = DataUtil.Products,
                GroupBySettings =
                {
                    AllowGroupByArea = GroupByAreaLocation.Top,
                    GroupByOperation = GroupByOperation.MergeCells
                }
            };


            TextColumn productNameColumn = new TextColumn { Key = "ProductName" };
            xamGrid.Columns.Add(productNameColumn);

            var buttonTemplate = this.Resources["CustomButtonTemplate"] as DataTemplate;
            UnboundColumn unboundButtonColumn = new UnboundColumn
            {
                Key = "ButtonColumn",
                ItemTemplate = buttonTemplate,
                HeaderText = "CategoryID",
                SortComparer = this.Resources["CustomSortComparer"] as CustomSortComparer,
                IsSortable = true,
                IsGroupBy = true
            };


            xamGrid.Columns.Add(unboundButtonColumn);

            xamGrid.GroupBySettings.AllowGroupByArea = GroupByAreaLocation.Top;
            xamGrid.GroupBySettings.GroupByOperation = GroupByOperation.MergeCells;

            Root.Children.Add(xamGrid);
        }

        private void Button_Click(object sender, RoutedEventArgs e)
        {
            Debug.WriteLine("Button Clicked!");
        }
    }

    public class CustomSortComparer : IComparer<Product>
    {
        public int Compare(Product x, Product y)
        {
            int x1 = x.ProductID;
            int y1 = y.ProductID;
            return x1.CompareTo(y1);
        }
    }
}
